@@ -1,18 +1,18 @@
-## ----setopts,echo=FALSE--------------------------------------------------
-require("knitr")
+## ----setopts,echo=FALSE,message=FALSE-----------------------------------------
+library("knitr")
 opts_chunk$set(fig.width=5,fig.height=5,
                out.width="0.8\\textwidth",echo=TRUE)
 Rver <- paste(R.version$major,R.version$minor,sep=".")
 used.pkgs <- c("glmmTMB","bbmle")  ## packages to report below
 
-## ----pkgversions,echo=FALSE----------------------------------------------
+## ----pkgversions,echo=FALSE---------------------------------------------------
 pkgver <- vapply(sort(used.pkgs),function(x) as.character(packageVersion(x)),"")
 print(pkgver,quote=FALSE)
 
-## ----citation,echo=FALSE,results="asis"----------------------------------
+## ----citation,echo=FALSE,results="asis"---------------------------------------
 print(citation("glmmTMB"),style="latex")
 
-## ----pkgs,message=FALSE--------------------------------------------------
+## ----pkgs,message=FALSE-------------------------------------------------------
 library("glmmTMB")
 library("bbmle")    ## for AICtab
 library("ggplot2")
@@ -20,13 +20,13 @@ library("ggplot2")
 theme_set(theme_bw()+
   theme(panel.spacing=grid::unit(0,"lines")))
 
-## ----owltransform,warning=FALSE------------------------------------------
+## ----owltransform,warning=FALSE-----------------------------------------------
 Owls <- transform(Owls,
                   Nest=reorder(Nest,NegPerChick),
                   NCalls=SiblingNegotiation,
                   FT=FoodTreatment)
 
-## ----owlplot1,echo=FALSE,message=FALSE,warning=FALSE,eval=FALSE----------
+## ----owlplot1,echo=FALSE,message=FALSE,warning=FALSE,eval=FALSE---------------
 #  G0 <- ggplot(Owls,aes(x=reorder(Nest,NegPerChick),
 #                        y=NegPerChick))+
 #    labs(x="Nest",y="Negotiations per chick")+coord_flip()+
@@ -37,47 +37,47 @@ Owls <- transform(Owls,
 #      theme(axis.title.x=element_text(hjust=0.5,size=12),
 #           axis.text.y=element_text(size=7))
 
-## ----time1,echo=FALSE,cache=TRUE-----------------------------------------
+## ----time1,echo=FALSE,cache=TRUE----------------------------------------------
 gt1 <- system.time(glmmTMB(NCalls~(FT+ArrivalTime)*SexParent+
                                      offset(log(BroodSize))+(1|Nest),
                                      ziformula=~1,
                                      data=Owls,
                                      family=poisson))
 
-## ----glmmTMBfit----------------------------------------------------------
+## ----glmmTMBfit---------------------------------------------------------------
 fit_zipoisson <- glmmTMB(NCalls~(FT+ArrivalTime)*SexParent+
                                      offset(log(BroodSize))+(1|Nest),
                                      data=Owls,
                                      ziformula=~1,
                                      family=poisson)
 
-## ----zipoisssum----------------------------------------------------------
+## ----zipoisssum---------------------------------------------------------------
 summary(fit_zipoisson)
 
-## ----glmmTMBnbinomfit----------------------------------------------------
+## ----glmmTMBnbinomfit---------------------------------------------------------
 fit_zinbinom <- update(fit_zipoisson,family=nbinom2)
 
-## ----glmmTMBnbinom1fit---------------------------------------------------
+## ----glmmTMBnbinom1fit--------------------------------------------------------
 fit_zinbinom1 <- update(fit_zipoisson,family=nbinom1)
 
-## ----glmmTMBnbinom1vfit--------------------------------------------------
+## ----glmmTMBnbinom1vfit-------------------------------------------------------
 fit_zinbinom1_bs <- update(fit_zinbinom1,
                            . ~ (FT+ArrivalTime)*SexParent+
                                BroodSize+(1|Nest))
 
-## ----aictab--------------------------------------------------------------
+## ----aictab-------------------------------------------------------------------
 AICtab(fit_zipoisson,fit_zinbinom,fit_zinbinom1,fit_zinbinom1_bs)
 
-## ----glmmTMBnbinomhfit,cache=TRUE----------------------------------------
+## ----glmmTMBnbinomhfit,cache=TRUE---------------------------------------------
 fit_hnbinom1 <-  update(fit_zinbinom1_bs,
                         ziformula=~.,
                         data=Owls,
                         family=list(family="truncated_nbinom1",link="log"))
 
-## ----hurdle_AIC----------------------------------------------------------
+## ----hurdle_AIC---------------------------------------------------------------
 AICtab(fit_zipoisson,fit_zinbinom,fit_zinbinom1,fit_zinbinom1_bs,fit_hnbinom1)
 
-## ----contraception_sum,echo=FALSE----------------------------------------
+## ----contraception_sum,echo=FALSE---------------------------------------------
 data("Contraception",package="mlmRev")
 nc <- nrow(Contraception)
 nl <- length(levels(Contraception$district))
