@@ -3,9 +3,9 @@ stopifnot(require("testthat"),
 
 context("Testing dispersion")
 
-sim1=function(nfac=40, nt=100, facsd=.1, tsd=.15, mu=0, residsd=1)
+sim1=function(nfac=24, nt=100, facsd=.1, tsd=.15, mu=0, residsd=1)
 {
-	dat=expand.grid(fac=factor(letters[1:nfac]), t= 1:nt)
+	dat=expand.grid(fac=factor(1:nfac, levels=1:nfac), t= 1:nt)
 	n=nrow(dat)
 	dat$REfac=rnorm(nfac, sd= facsd)[dat$fac]
 	dat$REt=rnorm(nt, sd= tsd)[dat$t]
@@ -20,25 +20,34 @@ d1=sim1(mu=100, residsd =10)
 d2=sim1(mu=200, residsd =5)
 
 d1=transform(d1, 
-	fac=paste0(fac, 1),
+	fac=paste0(fac, "_D10"),
 	disp="ten")
 	
 d2=transform(d2, 
-	fac=paste0(fac, 2),
+	fac=paste0(fac, "_D5"),
 	disp="five")
 
 ## global assignment for testthat
 dat <<- rbind(d1, d2)
+dat$disp = factor(dat$disp, levels = c("ten", "five"))
 m0 <<- glmmTMB(x~disp+(1|fac), dispformula=~disp, dat)
 
 test_that("disp calc", {
     expect_equal(unname(fixef(m0)$disp), c(log(10^2), log(5^2)-log(10^2)), tol=1e-2)
 })
 
+test_that("predict dispersion", {
+    expect_equal(predict(m0, type="disp"), c(rep(10, 24*100), rep(5, 24*100)), tol=1e-2)
+})
+
 dat2 <<- rbind(head(d1, 50), head(d2, 50)) #smaller for faster fitting when not checking estimates
-nbm0 <<- glmmTMB(round(x)~disp+(1|fac), ziformula=~0, dispformula=~disp, dat2, family=nbinom1, se=FALSE)
+## suppress "... false convergence (8) ..."
+suppressWarnings(nbm0 <<-
+            glmmTMB(round(x)~disp+(1|fac), ziformula=~0, dispformula=~disp, dat2, family=nbinom1, se=FALSE)
+          ) 
 pm0 <<- update(nbm0, family=poisson)
-nbm1 <<- update(pm0, family=nbinom1)
+## suppress "... false convergence (8) ..."
+nbm1 <<- suppressWarnings(update(pm0, family=nbinom1))
 test_that("update maintains dispformula in call", {
 	expect_equal(getCall(nbm0), getCall(nbm1))
-})
\ No newline at end of file
+})
